Crate compile_time_macros

Crate compile_time_macros 

This crate provides macros for getting compile time information.

This crate should not be used directly; use compile-time instead.

Macros

command_bytes
Runs the given command and returns its standard output as a &'static [u8].
command_str
Runs the given command and returns its standard output as a &'static str.
date
Returns the compile date as time::Date.
date_str
Returns the compile date as &'static str in yyyy-MM-dd format.
datetime
Returns the compile date and time as time::OffsetDateTime.
datetime_str
Returns the compile date and time as &'static str in yyyy-MM-ddThh:mm:ssZ format.
rustc_version
Returns the Rust compiler version as semver::Version.
rustc_version_build
Returns the Rust compiler build version as a &'static str.
rustc_version_major
Returns the Rust compiler major version as integer literal.
rustc_version_minor
Returns the Rust compiler minor version as integer literal.
rustc_version_patch
Returns the Rust compiler patch version as integer literal.
rustc_version_pre
Returns the Rust compiler pre version as &'static str.
rustc_version_str
Returns the Rust compiler version as &'static str.
time
Returns the compile time as time::Time.
time_str
Returns the compile time as &'static str in hh:mm:ss format.
unix
Returns the compile date and time as UNIX timestamp in seconds.