command_bytes

Macro command_bytes 

command_bytes!() { /* proc-macro */ }
Runs the given command and returns its standard output as a &'static [u8].

Produces a compile error if the command fails or of the output is not valid UTF-8.

Example

const MAGIC_NUMBER: &[u8] = compile_time::command_bytes!("echo", "42");

assert_eq!(MAGIC_NUMBER, b"42\n");