command_str!() { /* proc-macro */ }Expand description
Runs the given command and returns its standard output as a &'static str.
Produces a compile error if the command fails or of the output is not valid UTF-8.
Example
const MAGIC_NUMBER: &str = compile_time::command_str!("echo", "42");
assert_eq!(MAGIC_NUMBER, "42\n");